package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataArrangeEntity;
import com.czsj.dataCenter.service.IDataArrangeEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 任务编排信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/arrange")
public class DataArrangeEntityController extends BaseController
{
    @Autowired
    private IDataArrangeEntityService dataArrangeEntityService;

    /**
     * 查询任务编排信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrange:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataArrangeEntity dataArrangeEntity)
    {
        startPage();
        List<DataArrangeEntity> list = dataArrangeEntityService.selectDataArrangeEntityList(dataArrangeEntity);
        return getDataTable(list);
    }

    /**
     * 导出任务编排信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrange:export')")
    @Log(title = "任务编排信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataArrangeEntity dataArrangeEntity)
    {
        List<DataArrangeEntity> list = dataArrangeEntityService.selectDataArrangeEntityList(dataArrangeEntity);
        ExcelUtil<DataArrangeEntity> util = new ExcelUtil<DataArrangeEntity>(DataArrangeEntity.class);
        util.exportExcel(response, list, "任务编排信息数据");
    }

    /**
     * 获取任务编排信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrange:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataArrangeEntityService.selectDataArrangeEntityById(id));
    }

    /**
     * 新增任务编排信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrange:add')")
    @Log(title = "任务编排信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataArrangeEntity dataArrangeEntity)
    {
        return toAjax(dataArrangeEntityService.insertDataArrangeEntity(dataArrangeEntity));
    }

    /**
     * 修改任务编排信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrange:edit')")
    @Log(title = "任务编排信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataArrangeEntity dataArrangeEntity)
    {
        return toAjax(dataArrangeEntityService.updateDataArrangeEntity(dataArrangeEntity));
    }

    /**
     * 删除任务编排信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrange:remove')")
    @Log(title = "任务编排信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataArrangeEntityService.deleteDataArrangeEntityByIds(ids));
    }
}
