package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataArrangeLogEntity;
import com.czsj.dataCenter.service.IDataArrangeLogEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 编排日志信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/arrangeLog")
public class DataArrangeLogEntityController extends BaseController
{
    @Autowired
    private IDataArrangeLogEntityService dataArrangeLogEntityService;

    /**
     * 查询编排日志信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrangeLog:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataArrangeLogEntity dataArrangeLogEntity)
    {
        startPage();
        List<DataArrangeLogEntity> list = dataArrangeLogEntityService.selectDataArrangeLogEntityList(dataArrangeLogEntity);
        return getDataTable(list);
    }

    /**
     * 导出编排日志信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrangeLog:export')")
    @Log(title = "编排日志信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataArrangeLogEntity dataArrangeLogEntity)
    {
        List<DataArrangeLogEntity> list = dataArrangeLogEntityService.selectDataArrangeLogEntityList(dataArrangeLogEntity);
        ExcelUtil<DataArrangeLogEntity> util = new ExcelUtil<DataArrangeLogEntity>(DataArrangeLogEntity.class);
        util.exportExcel(response, list, "编排日志信息数据");
    }

    /**
     * 获取编排日志信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrangeLog:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataArrangeLogEntityService.selectDataArrangeLogEntityById(id));
    }

    /**
     * 新增编排日志信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrangeLog:add')")
    @Log(title = "编排日志信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataArrangeLogEntity dataArrangeLogEntity)
    {
        return toAjax(dataArrangeLogEntityService.insertDataArrangeLogEntity(dataArrangeLogEntity));
    }

    /**
     * 修改编排日志信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrangeLog:edit')")
    @Log(title = "编排日志信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataArrangeLogEntity dataArrangeLogEntity)
    {
        return toAjax(dataArrangeLogEntityService.updateDataArrangeLogEntity(dataArrangeLogEntity));
    }

    /**
     * 删除编排日志信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:arrangeLog:remove')")
    @Log(title = "编排日志信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataArrangeLogEntityService.deleteDataArrangeLogEntityByIds(ids));
    }
}
