package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataBusinessEntity;
import com.czsj.dataCenter.service.IDataBusinessEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 业务分类信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/business")
public class DataBusinessEntityController extends BaseController
{
    @Autowired
    private IDataBusinessEntityService dataBusinessEntityService;

    /**
     * 查询业务分类信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:business:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataBusinessEntity dataBusinessEntity)
    {
        startPage();
        List<DataBusinessEntity> list = dataBusinessEntityService.selectDataBusinessEntityList(dataBusinessEntity);
        return getDataTable(list);
    }

    /**
     * 导出业务分类信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:business:export')")
    @Log(title = "业务分类信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataBusinessEntity dataBusinessEntity)
    {
        List<DataBusinessEntity> list = dataBusinessEntityService.selectDataBusinessEntityList(dataBusinessEntity);
        ExcelUtil<DataBusinessEntity> util = new ExcelUtil<DataBusinessEntity>(DataBusinessEntity.class);
        util.exportExcel(response, list, "业务分类信息数据");
    }

    /**
     * 获取业务分类信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:business:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataBusinessEntityService.selectDataBusinessEntityById(id));
    }

    /**
     * 新增业务分类信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:business:add')")
    @Log(title = "业务分类信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataBusinessEntity dataBusinessEntity)
    {
        return toAjax(dataBusinessEntityService.insertDataBusinessEntity(dataBusinessEntity));
    }

    /**
     * 修改业务分类信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:business:edit')")
    @Log(title = "业务分类信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataBusinessEntity dataBusinessEntity)
    {
        return toAjax(dataBusinessEntityService.updateDataBusinessEntity(dataBusinessEntity));
    }

    /**
     * 删除业务分类信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:business:remove')")
    @Log(title = "业务分类信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataBusinessEntityService.deleteDataBusinessEntityByIds(ids));
    }
}
