package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataInterfaceEntity;
import com.czsj.dataCenter.service.IDataInterfaceEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 接口信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/interface")
public class DataInterfaceEntityController extends BaseController
{
    @Autowired
    private IDataInterfaceEntityService dataInterfaceEntityService;

    /**
     * 查询接口信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interface:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataInterfaceEntity dataInterfaceEntity)
    {
        startPage();
        List<DataInterfaceEntity> list = dataInterfaceEntityService.selectDataInterfaceEntityList(dataInterfaceEntity);
        return getDataTable(list);
    }

    /**
     * 导出接口信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interface:export')")
    @Log(title = "接口信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataInterfaceEntity dataInterfaceEntity)
    {
        List<DataInterfaceEntity> list = dataInterfaceEntityService.selectDataInterfaceEntityList(dataInterfaceEntity);
        ExcelUtil<DataInterfaceEntity> util = new ExcelUtil<DataInterfaceEntity>(DataInterfaceEntity.class);
        util.exportExcel(response, list, "接口信息数据");
    }

    /**
     * 获取接口信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interface:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataInterfaceEntityService.selectDataInterfaceEntityById(id));
    }

    /**
     * 新增接口信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interface:add')")
    @Log(title = "接口信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataInterfaceEntity dataInterfaceEntity)
    {
        return toAjax(dataInterfaceEntityService.insertDataInterfaceEntity(dataInterfaceEntity));
    }

    /**
     * 修改接口信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interface:edit')")
    @Log(title = "接口信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataInterfaceEntity dataInterfaceEntity)
    {
        return toAjax(dataInterfaceEntityService.updateDataInterfaceEntity(dataInterfaceEntity));
    }

    /**
     * 删除接口信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interface:remove')")
    @Log(title = "接口信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataInterfaceEntityService.deleteDataInterfaceEntityByIds(ids));
    }
}
