package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataInterfaceParamsEntity;
import com.czsj.dataCenter.service.IDataInterfaceParamsEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 接口参数信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/interfaceParams")
public class DataInterfaceParamsEntityController extends BaseController
{
    @Autowired
    private IDataInterfaceParamsEntityService dataInterfaceParamsEntityService;

    /**
     * 查询接口参数信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interfaceParams:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataInterfaceParamsEntity dataInterfaceParamsEntity)
    {
        startPage();
        List<DataInterfaceParamsEntity> list = dataInterfaceParamsEntityService.selectDataInterfaceParamsEntityList(dataInterfaceParamsEntity);
        return getDataTable(list);
    }

    /**
     * 导出接口参数信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interfaceParams:export')")
    @Log(title = "接口参数信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataInterfaceParamsEntity dataInterfaceParamsEntity)
    {
        List<DataInterfaceParamsEntity> list = dataInterfaceParamsEntityService.selectDataInterfaceParamsEntityList(dataInterfaceParamsEntity);
        ExcelUtil<DataInterfaceParamsEntity> util = new ExcelUtil<DataInterfaceParamsEntity>(DataInterfaceParamsEntity.class);
        util.exportExcel(response, list, "接口参数信息数据");
    }

    /**
     * 获取接口参数信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interfaceParams:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataInterfaceParamsEntityService.selectDataInterfaceParamsEntityById(id));
    }

    /**
     * 新增接口参数信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interfaceParams:add')")
    @Log(title = "接口参数信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataInterfaceParamsEntity dataInterfaceParamsEntity)
    {
        return toAjax(dataInterfaceParamsEntityService.insertDataInterfaceParamsEntity(dataInterfaceParamsEntity));
    }

    /**
     * 修改接口参数信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interfaceParams:edit')")
    @Log(title = "接口参数信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataInterfaceParamsEntity dataInterfaceParamsEntity)
    {
        return toAjax(dataInterfaceParamsEntityService.updateDataInterfaceParamsEntity(dataInterfaceParamsEntity));
    }

    /**
     * 删除接口参数信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:interfaceParams:remove')")
    @Log(title = "接口参数信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataInterfaceParamsEntityService.deleteDataInterfaceParamsEntityByIds(ids));
    }
}
