package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataMappingArgsEntity;
import com.czsj.dataCenter.service.IDataMappingArgsEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 配置执行类参数信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/mappingArgs")
public class DataMappingArgsEntityController extends BaseController
{
    @Autowired
    private IDataMappingArgsEntityService dataMappingArgsEntityService;

    /**
     * 查询配置执行类参数信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mappingArgs:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataMappingArgsEntity dataMappingArgsEntity)
    {
        startPage();
        List<DataMappingArgsEntity> list = dataMappingArgsEntityService.selectDataMappingArgsEntityList(dataMappingArgsEntity);
        return getDataTable(list);
    }

    /**
     * 导出配置执行类参数信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mappingArgs:export')")
    @Log(title = "配置执行类参数信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataMappingArgsEntity dataMappingArgsEntity)
    {
        List<DataMappingArgsEntity> list = dataMappingArgsEntityService.selectDataMappingArgsEntityList(dataMappingArgsEntity);
        ExcelUtil<DataMappingArgsEntity> util = new ExcelUtil<DataMappingArgsEntity>(DataMappingArgsEntity.class);
        util.exportExcel(response, list, "配置执行类参数信息数据");
    }

    /**
     * 获取配置执行类参数信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mappingArgs:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataMappingArgsEntityService.selectDataMappingArgsEntityById(id));
    }

    /**
     * 新增配置执行类参数信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mappingArgs:add')")
    @Log(title = "配置执行类参数信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataMappingArgsEntity dataMappingArgsEntity)
    {
        return toAjax(dataMappingArgsEntityService.insertDataMappingArgsEntity(dataMappingArgsEntity));
    }

    /**
     * 修改配置执行类参数信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mappingArgs:edit')")
    @Log(title = "配置执行类参数信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataMappingArgsEntity dataMappingArgsEntity)
    {
        return toAjax(dataMappingArgsEntityService.updateDataMappingArgsEntity(dataMappingArgsEntity));
    }

    /**
     * 删除配置执行类参数信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mappingArgs:remove')")
    @Log(title = "配置执行类参数信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataMappingArgsEntityService.deleteDataMappingArgsEntityByIds(ids));
    }
}
