package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataMappingEntity;
import com.czsj.dataCenter.service.IDataMappingEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 配置执行类映射信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/mapping")
public class DataMappingEntityController extends BaseController
{
    @Autowired
    private IDataMappingEntityService dataMappingEntityService;

    /**
     * 查询配置执行类映射信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mapping:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataMappingEntity dataMappingEntity)
    {
        startPage();
        List<DataMappingEntity> list = dataMappingEntityService.selectDataMappingEntityList(dataMappingEntity);
        return getDataTable(list);
    }

    /**
     * 导出配置执行类映射信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mapping:export')")
    @Log(title = "配置执行类映射信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataMappingEntity dataMappingEntity)
    {
        List<DataMappingEntity> list = dataMappingEntityService.selectDataMappingEntityList(dataMappingEntity);
        ExcelUtil<DataMappingEntity> util = new ExcelUtil<DataMappingEntity>(DataMappingEntity.class);
        util.exportExcel(response, list, "配置执行类映射信息数据");
    }

    /**
     * 获取配置执行类映射信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mapping:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataMappingEntityService.selectDataMappingEntityById(id));
    }

    /**
     * 新增配置执行类映射信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mapping:add')")
    @Log(title = "配置执行类映射信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataMappingEntity dataMappingEntity)
    {
        return toAjax(dataMappingEntityService.insertDataMappingEntity(dataMappingEntity));
    }

    /**
     * 修改配置执行类映射信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mapping:edit')")
    @Log(title = "配置执行类映射信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataMappingEntity dataMappingEntity)
    {
        return toAjax(dataMappingEntityService.updateDataMappingEntity(dataMappingEntity));
    }

    /**
     * 删除配置执行类映射信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:mapping:remove')")
    @Log(title = "配置执行类映射信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataMappingEntityService.deleteDataMappingEntityByIds(ids));
    }
}
