package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataProcessEntity;
import com.czsj.dataCenter.service.IDataProcessEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 节点流程信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/process")
public class DataProcessEntityController extends BaseController
{
    @Autowired
    private IDataProcessEntityService dataProcessEntityService;

    /**
     * 查询节点流程信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:process:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataProcessEntity dataProcessEntity)
    {
        startPage();
        List<DataProcessEntity> list = dataProcessEntityService.selectDataProcessEntityList(dataProcessEntity);
        return getDataTable(list);
    }

    /**
     * 导出节点流程信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:process:export')")
    @Log(title = "节点流程信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataProcessEntity dataProcessEntity)
    {
        List<DataProcessEntity> list = dataProcessEntityService.selectDataProcessEntityList(dataProcessEntity);
        ExcelUtil<DataProcessEntity> util = new ExcelUtil<DataProcessEntity>(DataProcessEntity.class);
        util.exportExcel(response, list, "节点流程信息数据");
    }

    /**
     * 获取节点流程信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:process:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataProcessEntityService.selectDataProcessEntityById(id));
    }

    /**
     * 新增节点流程信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:process:add')")
    @Log(title = "节点流程信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataProcessEntity dataProcessEntity)
    {
        return toAjax(dataProcessEntityService.insertDataProcessEntity(dataProcessEntity));
    }

    /**
     * 修改节点流程信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:process:edit')")
    @Log(title = "节点流程信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataProcessEntity dataProcessEntity)
    {
        return toAjax(dataProcessEntityService.updateDataProcessEntity(dataProcessEntity));
    }

    /**
     * 删除节点流程信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:process:remove')")
    @Log(title = "节点流程信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataProcessEntityService.deleteDataProcessEntityByIds(ids));
    }
}
