package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataSingleTaskConfigEntity;
import com.czsj.dataCenter.service.IDataSingleTaskConfigEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 单任务配置信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/singleTaskConfig")
public class DataSingleTaskConfigEntityController extends BaseController
{
    @Autowired
    private IDataSingleTaskConfigEntityService dataSingleTaskConfigEntityService;

    /**
     * 查询单任务配置信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:singleTaskConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataSingleTaskConfigEntity dataSingleTaskConfigEntity)
    {
        startPage();
        List<DataSingleTaskConfigEntity> list = dataSingleTaskConfigEntityService.selectDataSingleTaskConfigEntityList(dataSingleTaskConfigEntity);
        return getDataTable(list);
    }

    /**
     * 导出单任务配置信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:singleTaskConfig:export')")
    @Log(title = "单任务配置信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataSingleTaskConfigEntity dataSingleTaskConfigEntity)
    {
        List<DataSingleTaskConfigEntity> list = dataSingleTaskConfigEntityService.selectDataSingleTaskConfigEntityList(dataSingleTaskConfigEntity);
        ExcelUtil<DataSingleTaskConfigEntity> util = new ExcelUtil<DataSingleTaskConfigEntity>(DataSingleTaskConfigEntity.class);
        util.exportExcel(response, list, "单任务配置信息数据");
    }

    /**
     * 获取单任务配置信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:singleTaskConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataSingleTaskConfigEntityService.selectDataSingleTaskConfigEntityById(id));
    }

    /**
     * 新增单任务配置信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:singleTaskConfig:add')")
    @Log(title = "单任务配置信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataSingleTaskConfigEntity dataSingleTaskConfigEntity)
    {
        return toAjax(dataSingleTaskConfigEntityService.insertDataSingleTaskConfigEntity(dataSingleTaskConfigEntity));
    }

    /**
     * 修改单任务配置信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:singleTaskConfig:edit')")
    @Log(title = "单任务配置信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataSingleTaskConfigEntity dataSingleTaskConfigEntity)
    {
        return toAjax(dataSingleTaskConfigEntityService.updateDataSingleTaskConfigEntity(dataSingleTaskConfigEntity));
    }

    /**
     * 删除单任务配置信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:singleTaskConfig:remove')")
    @Log(title = "单任务配置信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataSingleTaskConfigEntityService.deleteDataSingleTaskConfigEntityByIds(ids));
    }
}
