package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataSourceEntity;
import com.czsj.dataCenter.service.IDataSourceEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 数据源信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/source")
public class DataSourceEntityController extends BaseController
{
    @Autowired
    private IDataSourceEntityService dataSourceEntityService;

    /**
     * 查询数据源信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:source:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataSourceEntity dataSourceEntity)
    {
        startPage();
        List<DataSourceEntity> list = dataSourceEntityService.selectDataSourceEntityList(dataSourceEntity);
        return getDataTable(list);
    }

    /**
     * 导出数据源信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:source:export')")
    @Log(title = "数据源信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataSourceEntity dataSourceEntity)
    {
        List<DataSourceEntity> list = dataSourceEntityService.selectDataSourceEntityList(dataSourceEntity);
        ExcelUtil<DataSourceEntity> util = new ExcelUtil<DataSourceEntity>(DataSourceEntity.class);
        util.exportExcel(response, list, "数据源信息数据");
    }

    /**
     * 获取数据源信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:source:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataSourceEntityService.selectDataSourceEntityById(id));
    }

    /**
     * 新增数据源信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:source:add')")
    @Log(title = "数据源信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataSourceEntity dataSourceEntity)
    {
        return toAjax(dataSourceEntityService.insertDataSourceEntity(dataSourceEntity));
    }

    /**
     * 修改数据源信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:source:edit')")
    @Log(title = "数据源信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataSourceEntity dataSourceEntity)
    {
        return toAjax(dataSourceEntityService.updateDataSourceEntity(dataSourceEntity));
    }

    /**
     * 删除数据源信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:source:remove')")
    @Log(title = "数据源信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataSourceEntityService.deleteDataSourceEntityByIds(ids));
    }
}
