package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataSourceTypeEntity;
import com.czsj.dataCenter.service.IDataSourceTypeEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 数据源分类信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/sourceType")
public class DataSourceTypeEntityController extends BaseController
{
    @Autowired
    private IDataSourceTypeEntityService dataSourceTypeEntityService;

    /**
     * 查询数据源分类信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:sourceType:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataSourceTypeEntity dataSourceTypeEntity)
    {
        startPage();
        List<DataSourceTypeEntity> list = dataSourceTypeEntityService.selectDataSourceTypeEntityList(dataSourceTypeEntity);
        return getDataTable(list);
    }

    /**
     * 导出数据源分类信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:sourceType:export')")
    @Log(title = "数据源分类信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataSourceTypeEntity dataSourceTypeEntity)
    {
        List<DataSourceTypeEntity> list = dataSourceTypeEntityService.selectDataSourceTypeEntityList(dataSourceTypeEntity);
        ExcelUtil<DataSourceTypeEntity> util = new ExcelUtil<DataSourceTypeEntity>(DataSourceTypeEntity.class);
        util.exportExcel(response, list, "数据源分类信息数据");
    }

    /**
     * 获取数据源分类信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:sourceType:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataSourceTypeEntityService.selectDataSourceTypeEntityById(id));
    }

    /**
     * 新增数据源分类信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:sourceType:add')")
    @Log(title = "数据源分类信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataSourceTypeEntity dataSourceTypeEntity)
    {
        return toAjax(dataSourceTypeEntityService.insertDataSourceTypeEntity(dataSourceTypeEntity));
    }

    /**
     * 修改数据源分类信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:sourceType:edit')")
    @Log(title = "数据源分类信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataSourceTypeEntity dataSourceTypeEntity)
    {
        return toAjax(dataSourceTypeEntityService.updateDataSourceTypeEntity(dataSourceTypeEntity));
    }

    /**
     * 删除数据源分类信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:sourceType:remove')")
    @Log(title = "数据源分类信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataSourceTypeEntityService.deleteDataSourceTypeEntityByIds(ids));
    }
}
