package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataTable;
import com.czsj.dataCenter.service.IDataTableService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 数据库信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/table")
public class DataTableController extends BaseController
{
    @Autowired
    private IDataTableService dataTableService;

    /**
     * 查询数据库信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:table:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataTable dataTable)
    {
        startPage();
        List<DataTable> list = dataTableService.selectDataTableList(dataTable);
        return getDataTable(list);
    }

    /**
     * 导出数据库信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:table:export')")
    @Log(title = "数据库信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataTable dataTable)
    {
        List<DataTable> list = dataTableService.selectDataTableList(dataTable);
        ExcelUtil<DataTable> util = new ExcelUtil<DataTable>(DataTable.class);
        util.exportExcel(response, list, "数据库信息数据");
    }

    /**
     * 获取数据库信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:table:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataTableService.selectDataTableById(id));
    }

    /**
     * 新增数据库信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:table:add')")
    @Log(title = "数据库信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataTable dataTable)
    {
        return toAjax(dataTableService.insertDataTable(dataTable));
    }

    /**
     * 修改数据库信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:table:edit')")
    @Log(title = "数据库信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataTable dataTable)
    {
        return toAjax(dataTableService.updateDataTable(dataTable));
    }

    /**
     * 删除数据库信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:table:remove')")
    @Log(title = "数据库信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataTableService.deleteDataTableByIds(ids));
    }
}
