package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataTableField;
import com.czsj.dataCenter.service.IDataTableFieldService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 数据库字段信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/tableField")
public class DataTableFieldController extends BaseController
{
    @Autowired
    private IDataTableFieldService dataTableFieldService;

    /**
     * 查询数据库字段信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:tableField:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataTableField dataTableField)
    {
        startPage();
        List<DataTableField> list = dataTableFieldService.selectDataTableFieldList(dataTableField);
        return getDataTable(list);
    }

    /**
     * 导出数据库字段信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:tableField:export')")
    @Log(title = "数据库字段信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataTableField dataTableField)
    {
        List<DataTableField> list = dataTableFieldService.selectDataTableFieldList(dataTableField);
        ExcelUtil<DataTableField> util = new ExcelUtil<DataTableField>(DataTableField.class);
        util.exportExcel(response, list, "数据库字段信息数据");
    }

    /**
     * 获取数据库字段信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:tableField:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataTableFieldService.selectDataTableFieldById(id));
    }

    /**
     * 新增数据库字段信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:tableField:add')")
    @Log(title = "数据库字段信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataTableField dataTableField)
    {
        return toAjax(dataTableFieldService.insertDataTableField(dataTableField));
    }

    /**
     * 修改数据库字段信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:tableField:edit')")
    @Log(title = "数据库字段信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataTableField dataTableField)
    {
        return toAjax(dataTableFieldService.updateDataTableField(dataTableField));
    }

    /**
     * 删除数据库字段信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:tableField:remove')")
    @Log(title = "数据库字段信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataTableFieldService.deleteDataTableFieldByIds(ids));
    }
}
