package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataTaskConfigEntity;
import com.czsj.dataCenter.service.IDataTaskConfigEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 任务JOB块配置信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/taskConfig")
public class DataTaskConfigEntityController extends BaseController
{
    @Autowired
    private IDataTaskConfigEntityService dataTaskConfigEntityService;

    /**
     * 查询任务JOB块配置信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataTaskConfigEntity dataTaskConfigEntity)
    {
        startPage();
        List<DataTaskConfigEntity> list = dataTaskConfigEntityService.selectDataTaskConfigEntityList(dataTaskConfigEntity);
        return getDataTable(list);
    }

    /**
     * 导出任务JOB块配置信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskConfig:export')")
    @Log(title = "任务JOB块配置信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataTaskConfigEntity dataTaskConfigEntity)
    {
        List<DataTaskConfigEntity> list = dataTaskConfigEntityService.selectDataTaskConfigEntityList(dataTaskConfigEntity);
        ExcelUtil<DataTaskConfigEntity> util = new ExcelUtil<DataTaskConfigEntity>(DataTaskConfigEntity.class);
        util.exportExcel(response, list, "任务JOB块配置信息数据");
    }

    /**
     * 获取任务JOB块配置信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataTaskConfigEntityService.selectDataTaskConfigEntityById(id));
    }

    /**
     * 新增任务JOB块配置信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskConfig:add')")
    @Log(title = "任务JOB块配置信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataTaskConfigEntity dataTaskConfigEntity)
    {
        return toAjax(dataTaskConfigEntityService.insertDataTaskConfigEntity(dataTaskConfigEntity));
    }

    /**
     * 修改任务JOB块配置信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskConfig:edit')")
    @Log(title = "任务JOB块配置信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataTaskConfigEntity dataTaskConfigEntity)
    {
        return toAjax(dataTaskConfigEntityService.updateDataTaskConfigEntity(dataTaskConfigEntity));
    }

    /**
     * 删除任务JOB块配置信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskConfig:remove')")
    @Log(title = "任务JOB块配置信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataTaskConfigEntityService.deleteDataTaskConfigEntityByIds(ids));
    }
}
