package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataTaskCoreEntity;
import com.czsj.dataCenter.service.IDataTaskCoreEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 任务CORE块配置信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/taskCore")
public class DataTaskCoreEntityController extends BaseController
{
    @Autowired
    private IDataTaskCoreEntityService dataTaskCoreEntityService;

    /**
     * 查询任务CORE块配置信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskCore:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataTaskCoreEntity dataTaskCoreEntity)
    {
        startPage();
        List<DataTaskCoreEntity> list = dataTaskCoreEntityService.selectDataTaskCoreEntityList(dataTaskCoreEntity);
        return getDataTable(list);
    }

    /**
     * 导出任务CORE块配置信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskCore:export')")
    @Log(title = "任务CORE块配置信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataTaskCoreEntity dataTaskCoreEntity)
    {
        List<DataTaskCoreEntity> list = dataTaskCoreEntityService.selectDataTaskCoreEntityList(dataTaskCoreEntity);
        ExcelUtil<DataTaskCoreEntity> util = new ExcelUtil<DataTaskCoreEntity>(DataTaskCoreEntity.class);
        util.exportExcel(response, list, "任务CORE块配置信息数据");
    }

    /**
     * 获取任务CORE块配置信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskCore:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataTaskCoreEntityService.selectDataTaskCoreEntityById(id));
    }

    /**
     * 新增任务CORE块配置信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskCore:add')")
    @Log(title = "任务CORE块配置信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataTaskCoreEntity dataTaskCoreEntity)
    {
        return toAjax(dataTaskCoreEntityService.insertDataTaskCoreEntity(dataTaskCoreEntity));
    }

    /**
     * 修改任务CORE块配置信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskCore:edit')")
    @Log(title = "任务CORE块配置信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataTaskCoreEntity dataTaskCoreEntity)
    {
        return toAjax(dataTaskCoreEntityService.updateDataTaskCoreEntity(dataTaskCoreEntity));
    }

    /**
     * 删除任务CORE块配置信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskCore:remove')")
    @Log(title = "任务CORE块配置信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataTaskCoreEntityService.deleteDataTaskCoreEntityByIds(ids));
    }
}
