package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataTaskEntity;
import com.czsj.dataCenter.service.IDataTaskEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 任务主体信息Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/task")
public class DataTaskEntityController extends BaseController
{
    @Autowired
    private IDataTaskEntityService dataTaskEntityService;

    /**
     * 查询任务主体信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:task:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataTaskEntity dataTaskEntity)
    {
        startPage();
        List<DataTaskEntity> list = dataTaskEntityService.selectDataTaskEntityList(dataTaskEntity);
        return getDataTable(list);
    }

    /**
     * 导出任务主体信息列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:task:export')")
    @Log(title = "任务主体信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataTaskEntity dataTaskEntity)
    {
        List<DataTaskEntity> list = dataTaskEntityService.selectDataTaskEntityList(dataTaskEntity);
        ExcelUtil<DataTaskEntity> util = new ExcelUtil<DataTaskEntity>(DataTaskEntity.class);
        util.exportExcel(response, list, "任务主体信息数据");
    }

    /**
     * 获取任务主体信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:task:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataTaskEntityService.selectDataTaskEntityById(id));
    }

    /**
     * 新增任务主体信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:task:add')")
    @Log(title = "任务主体信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataTaskEntity dataTaskEntity)
    {
        return toAjax(dataTaskEntityService.insertDataTaskEntity(dataTaskEntity));
    }

    /**
     * 修改任务主体信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:task:edit')")
    @Log(title = "任务主体信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataTaskEntity dataTaskEntity)
    {
        return toAjax(dataTaskEntityService.updateDataTaskEntity(dataTaskEntity));
    }

    /**
     * 删除任务主体信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:task:remove')")
    @Log(title = "任务主体信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataTaskEntityService.deleteDataTaskEntityByIds(ids));
    }
}
