package com.czsj.web.controller.dataCenter;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.czsj.common.annotation.Log;
import com.czsj.common.core.controller.BaseController;
import com.czsj.common.core.domain.AjaxResult;
import com.czsj.common.enums.BusinessType;
import com.czsj.dataCenter.domain.DataTaskMakeUpEntity;
import com.czsj.dataCenter.service.IDataTaskMakeUpEntityService;
import com.czsj.common.utils.poi.ExcelUtil;
import com.czsj.common.core.page.TableDataInfo;

/**
 * 任务配置组成数据Controller
 * 
 * @author czsj
 * @date 2024-12-08
 */
@RestController
@RequestMapping("/dataCenter/taskMakeUp")
public class DataTaskMakeUpEntityController extends BaseController
{
    @Autowired
    private IDataTaskMakeUpEntityService dataTaskMakeUpEntityService;

    /**
     * 查询任务配置组成数据列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskMakeUp:list')")
    @GetMapping("/list")
    public TableDataInfo list(DataTaskMakeUpEntity dataTaskMakeUpEntity)
    {
        startPage();
        List<DataTaskMakeUpEntity> list = dataTaskMakeUpEntityService.selectDataTaskMakeUpEntityList(dataTaskMakeUpEntity);
        return getDataTable(list);
    }

    /**
     * 导出任务配置组成数据列表
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskMakeUp:export')")
    @Log(title = "任务配置组成数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DataTaskMakeUpEntity dataTaskMakeUpEntity)
    {
        List<DataTaskMakeUpEntity> list = dataTaskMakeUpEntityService.selectDataTaskMakeUpEntityList(dataTaskMakeUpEntity);
        ExcelUtil<DataTaskMakeUpEntity> util = new ExcelUtil<DataTaskMakeUpEntity>(DataTaskMakeUpEntity.class);
        util.exportExcel(response, list, "任务配置组成数据数据");
    }

    /**
     * 获取任务配置组成数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskMakeUp:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(dataTaskMakeUpEntityService.selectDataTaskMakeUpEntityById(id));
    }

    /**
     * 新增任务配置组成数据
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskMakeUp:add')")
    @Log(title = "任务配置组成数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DataTaskMakeUpEntity dataTaskMakeUpEntity)
    {
        return toAjax(dataTaskMakeUpEntityService.insertDataTaskMakeUpEntity(dataTaskMakeUpEntity));
    }

    /**
     * 修改任务配置组成数据
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskMakeUp:edit')")
    @Log(title = "任务配置组成数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DataTaskMakeUpEntity dataTaskMakeUpEntity)
    {
        return toAjax(dataTaskMakeUpEntityService.updateDataTaskMakeUpEntity(dataTaskMakeUpEntity));
    }

    /**
     * 删除任务配置组成数据
     */
    @PreAuthorize("@ss.hasPermi('dataCenter:taskMakeUp:remove')")
    @Log(title = "任务配置组成数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(dataTaskMakeUpEntityService.deleteDataTaskMakeUpEntityByIds(ids));
    }
}
