package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataArrangeLogEntityMapper;
import com.czsj.dataCenter.domain.DataArrangeLogEntity;
import com.czsj.dataCenter.service.IDataArrangeLogEntityService;

/**
 * 编排日志信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataArrangeLogEntityServiceImpl implements IDataArrangeLogEntityService 
{
    @Autowired
    private DataArrangeLogEntityMapper dataArrangeLogEntityMapper;

    /**
     * 查询编排日志信息
     * 
     * @param id 编排日志信息主键
     * @return 编排日志信息
     */
    @Override
    public DataArrangeLogEntity selectDataArrangeLogEntityById(Integer id)
    {
        return dataArrangeLogEntityMapper.selectDataArrangeLogEntityById(id);
    }

    /**
     * 查询编排日志信息列表
     * 
     * @param dataArrangeLogEntity 编排日志信息
     * @return 编排日志信息
     */
    @Override
    public List<DataArrangeLogEntity> selectDataArrangeLogEntityList(DataArrangeLogEntity dataArrangeLogEntity)
    {
        return dataArrangeLogEntityMapper.selectDataArrangeLogEntityList(dataArrangeLogEntity);
    }

    /**
     * 新增编排日志信息
     * 
     * @param dataArrangeLogEntity 编排日志信息
     * @return 结果
     */
    @Override
    public int insertDataArrangeLogEntity(DataArrangeLogEntity dataArrangeLogEntity)
    {
        dataArrangeLogEntity.setCreateTime(DateUtils.getNowDate());
        return dataArrangeLogEntityMapper.insertDataArrangeLogEntity(dataArrangeLogEntity);
    }

    /**
     * 修改编排日志信息
     * 
     * @param dataArrangeLogEntity 编排日志信息
     * @return 结果
     */
    @Override
    public int updateDataArrangeLogEntity(DataArrangeLogEntity dataArrangeLogEntity)
    {
        dataArrangeLogEntity.setUpdateTime(DateUtils.getNowDate());
        return dataArrangeLogEntityMapper.updateDataArrangeLogEntity(dataArrangeLogEntity);
    }

    /**
     * 批量删除编排日志信息
     * 
     * @param ids 需要删除的编排日志信息主键
     * @return 结果
     */
    @Override
    public int deleteDataArrangeLogEntityByIds(Integer[] ids)
    {
        return dataArrangeLogEntityMapper.deleteDataArrangeLogEntityByIds(ids);
    }

    /**
     * 删除编排日志信息信息
     * 
     * @param id 编排日志信息主键
     * @return 结果
     */
    @Override
    public int deleteDataArrangeLogEntityById(Integer id)
    {
        return dataArrangeLogEntityMapper.deleteDataArrangeLogEntityById(id);
    }
}
