package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataBusinessEntityMapper;
import com.czsj.dataCenter.domain.DataBusinessEntity;
import com.czsj.dataCenter.service.IDataBusinessEntityService;

/**
 * 业务分类信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataBusinessEntityServiceImpl implements IDataBusinessEntityService 
{
    @Autowired
    private DataBusinessEntityMapper dataBusinessEntityMapper;

    /**
     * 查询业务分类信息
     * 
     * @param id 业务分类信息主键
     * @return 业务分类信息
     */
    @Override
    public DataBusinessEntity selectDataBusinessEntityById(Integer id)
    {
        return dataBusinessEntityMapper.selectDataBusinessEntityById(id);
    }

    /**
     * 查询业务分类信息列表
     * 
     * @param dataBusinessEntity 业务分类信息
     * @return 业务分类信息
     */
    @Override
    public List<DataBusinessEntity> selectDataBusinessEntityList(DataBusinessEntity dataBusinessEntity)
    {
        return dataBusinessEntityMapper.selectDataBusinessEntityList(dataBusinessEntity);
    }

    /**
     * 新增业务分类信息
     * 
     * @param dataBusinessEntity 业务分类信息
     * @return 结果
     */
    @Override
    public int insertDataBusinessEntity(DataBusinessEntity dataBusinessEntity)
    {
        dataBusinessEntity.setCreateTime(DateUtils.getNowDate());
        return dataBusinessEntityMapper.insertDataBusinessEntity(dataBusinessEntity);
    }

    /**
     * 修改业务分类信息
     * 
     * @param dataBusinessEntity 业务分类信息
     * @return 结果
     */
    @Override
    public int updateDataBusinessEntity(DataBusinessEntity dataBusinessEntity)
    {
        dataBusinessEntity.setUpdateTime(DateUtils.getNowDate());
        return dataBusinessEntityMapper.updateDataBusinessEntity(dataBusinessEntity);
    }

    /**
     * 批量删除业务分类信息
     * 
     * @param ids 需要删除的业务分类信息主键
     * @return 结果
     */
    @Override
    public int deleteDataBusinessEntityByIds(Integer[] ids)
    {
        return dataBusinessEntityMapper.deleteDataBusinessEntityByIds(ids);
    }

    /**
     * 删除业务分类信息信息
     * 
     * @param id 业务分类信息主键
     * @return 结果
     */
    @Override
    public int deleteDataBusinessEntityById(Integer id)
    {
        return dataBusinessEntityMapper.deleteDataBusinessEntityById(id);
    }
}
