package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataInterfaceEntityMapper;
import com.czsj.dataCenter.domain.DataInterfaceEntity;
import com.czsj.dataCenter.service.IDataInterfaceEntityService;

/**
 * 接口信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataInterfaceEntityServiceImpl implements IDataInterfaceEntityService 
{
    @Autowired
    private DataInterfaceEntityMapper dataInterfaceEntityMapper;

    /**
     * 查询接口信息
     * 
     * @param id 接口信息主键
     * @return 接口信息
     */
    @Override
    public DataInterfaceEntity selectDataInterfaceEntityById(Integer id)
    {
        return dataInterfaceEntityMapper.selectDataInterfaceEntityById(id);
    }

    /**
     * 查询接口信息列表
     * 
     * @param dataInterfaceEntity 接口信息
     * @return 接口信息
     */
    @Override
    public List<DataInterfaceEntity> selectDataInterfaceEntityList(DataInterfaceEntity dataInterfaceEntity)
    {
        return dataInterfaceEntityMapper.selectDataInterfaceEntityList(dataInterfaceEntity);
    }

    /**
     * 新增接口信息
     * 
     * @param dataInterfaceEntity 接口信息
     * @return 结果
     */
    @Override
    public int insertDataInterfaceEntity(DataInterfaceEntity dataInterfaceEntity)
    {
        dataInterfaceEntity.setCreateTime(DateUtils.getNowDate());
        return dataInterfaceEntityMapper.insertDataInterfaceEntity(dataInterfaceEntity);
    }

    /**
     * 修改接口信息
     * 
     * @param dataInterfaceEntity 接口信息
     * @return 结果
     */
    @Override
    public int updateDataInterfaceEntity(DataInterfaceEntity dataInterfaceEntity)
    {
        dataInterfaceEntity.setUpdateTime(DateUtils.getNowDate());
        return dataInterfaceEntityMapper.updateDataInterfaceEntity(dataInterfaceEntity);
    }

    /**
     * 批量删除接口信息
     * 
     * @param ids 需要删除的接口信息主键
     * @return 结果
     */
    @Override
    public int deleteDataInterfaceEntityByIds(Integer[] ids)
    {
        return dataInterfaceEntityMapper.deleteDataInterfaceEntityByIds(ids);
    }

    /**
     * 删除接口信息信息
     * 
     * @param id 接口信息主键
     * @return 结果
     */
    @Override
    public int deleteDataInterfaceEntityById(Integer id)
    {
        return dataInterfaceEntityMapper.deleteDataInterfaceEntityById(id);
    }
}
