package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataMappingEntityMapper;
import com.czsj.dataCenter.domain.DataMappingEntity;
import com.czsj.dataCenter.service.IDataMappingEntityService;

/**
 * 配置执行类映射信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataMappingEntityServiceImpl implements IDataMappingEntityService 
{
    @Autowired
    private DataMappingEntityMapper dataMappingEntityMapper;

    /**
     * 查询配置执行类映射信息
     * 
     * @param id 配置执行类映射信息主键
     * @return 配置执行类映射信息
     */
    @Override
    public DataMappingEntity selectDataMappingEntityById(Integer id)
    {
        return dataMappingEntityMapper.selectDataMappingEntityById(id);
    }

    /**
     * 查询配置执行类映射信息列表
     * 
     * @param dataMappingEntity 配置执行类映射信息
     * @return 配置执行类映射信息
     */
    @Override
    public List<DataMappingEntity> selectDataMappingEntityList(DataMappingEntity dataMappingEntity)
    {
        return dataMappingEntityMapper.selectDataMappingEntityList(dataMappingEntity);
    }

    /**
     * 新增配置执行类映射信息
     * 
     * @param dataMappingEntity 配置执行类映射信息
     * @return 结果
     */
    @Override
    public int insertDataMappingEntity(DataMappingEntity dataMappingEntity)
    {
        dataMappingEntity.setCreateTime(DateUtils.getNowDate());
        return dataMappingEntityMapper.insertDataMappingEntity(dataMappingEntity);
    }

    /**
     * 修改配置执行类映射信息
     * 
     * @param dataMappingEntity 配置执行类映射信息
     * @return 结果
     */
    @Override
    public int updateDataMappingEntity(DataMappingEntity dataMappingEntity)
    {
        dataMappingEntity.setUpdateTime(DateUtils.getNowDate());
        return dataMappingEntityMapper.updateDataMappingEntity(dataMappingEntity);
    }

    /**
     * 批量删除配置执行类映射信息
     * 
     * @param ids 需要删除的配置执行类映射信息主键
     * @return 结果
     */
    @Override
    public int deleteDataMappingEntityByIds(Integer[] ids)
    {
        return dataMappingEntityMapper.deleteDataMappingEntityByIds(ids);
    }

    /**
     * 删除配置执行类映射信息信息
     * 
     * @param id 配置执行类映射信息主键
     * @return 结果
     */
    @Override
    public int deleteDataMappingEntityById(Integer id)
    {
        return dataMappingEntityMapper.deleteDataMappingEntityById(id);
    }
}
