package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataProcessEntityMapper;
import com.czsj.dataCenter.domain.DataProcessEntity;
import com.czsj.dataCenter.service.IDataProcessEntityService;

/**
 * 节点流程信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataProcessEntityServiceImpl implements IDataProcessEntityService 
{
    @Autowired
    private DataProcessEntityMapper dataProcessEntityMapper;

    /**
     * 查询节点流程信息
     * 
     * @param id 节点流程信息主键
     * @return 节点流程信息
     */
    @Override
    public DataProcessEntity selectDataProcessEntityById(Integer id)
    {
        return dataProcessEntityMapper.selectDataProcessEntityById(id);
    }

    /**
     * 查询节点流程信息列表
     * 
     * @param dataProcessEntity 节点流程信息
     * @return 节点流程信息
     */
    @Override
    public List<DataProcessEntity> selectDataProcessEntityList(DataProcessEntity dataProcessEntity)
    {
        return dataProcessEntityMapper.selectDataProcessEntityList(dataProcessEntity);
    }

    /**
     * 新增节点流程信息
     * 
     * @param dataProcessEntity 节点流程信息
     * @return 结果
     */
    @Override
    public int insertDataProcessEntity(DataProcessEntity dataProcessEntity)
    {
        dataProcessEntity.setCreateTime(DateUtils.getNowDate());
        return dataProcessEntityMapper.insertDataProcessEntity(dataProcessEntity);
    }

    /**
     * 修改节点流程信息
     * 
     * @param dataProcessEntity 节点流程信息
     * @return 结果
     */
    @Override
    public int updateDataProcessEntity(DataProcessEntity dataProcessEntity)
    {
        dataProcessEntity.setUpdateTime(DateUtils.getNowDate());
        return dataProcessEntityMapper.updateDataProcessEntity(dataProcessEntity);
    }

    /**
     * 批量删除节点流程信息
     * 
     * @param ids 需要删除的节点流程信息主键
     * @return 结果
     */
    @Override
    public int deleteDataProcessEntityByIds(Integer[] ids)
    {
        return dataProcessEntityMapper.deleteDataProcessEntityByIds(ids);
    }

    /**
     * 删除节点流程信息信息
     * 
     * @param id 节点流程信息主键
     * @return 结果
     */
    @Override
    public int deleteDataProcessEntityById(Integer id)
    {
        return dataProcessEntityMapper.deleteDataProcessEntityById(id);
    }
}
