package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataSingleTaskConfigEntityMapper;
import com.czsj.dataCenter.domain.DataSingleTaskConfigEntity;
import com.czsj.dataCenter.service.IDataSingleTaskConfigEntityService;

/**
 * 单任务配置信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataSingleTaskConfigEntityServiceImpl implements IDataSingleTaskConfigEntityService 
{
    @Autowired
    private DataSingleTaskConfigEntityMapper dataSingleTaskConfigEntityMapper;

    /**
     * 查询单任务配置信息
     * 
     * @param id 单任务配置信息主键
     * @return 单任务配置信息
     */
    @Override
    public DataSingleTaskConfigEntity selectDataSingleTaskConfigEntityById(Integer id)
    {
        return dataSingleTaskConfigEntityMapper.selectDataSingleTaskConfigEntityById(id);
    }

    /**
     * 查询单任务配置信息列表
     * 
     * @param dataSingleTaskConfigEntity 单任务配置信息
     * @return 单任务配置信息
     */
    @Override
    public List<DataSingleTaskConfigEntity> selectDataSingleTaskConfigEntityList(DataSingleTaskConfigEntity dataSingleTaskConfigEntity)
    {
        return dataSingleTaskConfigEntityMapper.selectDataSingleTaskConfigEntityList(dataSingleTaskConfigEntity);
    }

    /**
     * 新增单任务配置信息
     * 
     * @param dataSingleTaskConfigEntity 单任务配置信息
     * @return 结果
     */
    @Override
    public int insertDataSingleTaskConfigEntity(DataSingleTaskConfigEntity dataSingleTaskConfigEntity)
    {
        dataSingleTaskConfigEntity.setCreateTime(DateUtils.getNowDate());
        return dataSingleTaskConfigEntityMapper.insertDataSingleTaskConfigEntity(dataSingleTaskConfigEntity);
    }

    /**
     * 修改单任务配置信息
     * 
     * @param dataSingleTaskConfigEntity 单任务配置信息
     * @return 结果
     */
    @Override
    public int updateDataSingleTaskConfigEntity(DataSingleTaskConfigEntity dataSingleTaskConfigEntity)
    {
        dataSingleTaskConfigEntity.setUpdateTime(DateUtils.getNowDate());
        return dataSingleTaskConfigEntityMapper.updateDataSingleTaskConfigEntity(dataSingleTaskConfigEntity);
    }

    /**
     * 批量删除单任务配置信息
     * 
     * @param ids 需要删除的单任务配置信息主键
     * @return 结果
     */
    @Override
    public int deleteDataSingleTaskConfigEntityByIds(Integer[] ids)
    {
        return dataSingleTaskConfigEntityMapper.deleteDataSingleTaskConfigEntityByIds(ids);
    }

    /**
     * 删除单任务配置信息信息
     * 
     * @param id 单任务配置信息主键
     * @return 结果
     */
    @Override
    public int deleteDataSingleTaskConfigEntityById(Integer id)
    {
        return dataSingleTaskConfigEntityMapper.deleteDataSingleTaskConfigEntityById(id);
    }
}
