package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataSourceEntityMapper;
import com.czsj.dataCenter.domain.DataSourceEntity;
import com.czsj.dataCenter.service.IDataSourceEntityService;

/**
 * 数据源信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataSourceEntityServiceImpl implements IDataSourceEntityService 
{
    @Autowired
    private DataSourceEntityMapper dataSourceEntityMapper;

    /**
     * 查询数据源信息
     * 
     * @param id 数据源信息主键
     * @return 数据源信息
     */
    @Override
    public DataSourceEntity selectDataSourceEntityById(Integer id)
    {
        return dataSourceEntityMapper.selectDataSourceEntityById(id);
    }

    /**
     * 查询数据源信息列表
     * 
     * @param dataSourceEntity 数据源信息
     * @return 数据源信息
     */
    @Override
    public List<DataSourceEntity> selectDataSourceEntityList(DataSourceEntity dataSourceEntity)
    {
        return dataSourceEntityMapper.selectDataSourceEntityList(dataSourceEntity);
    }

    /**
     * 新增数据源信息
     * 
     * @param dataSourceEntity 数据源信息
     * @return 结果
     */
    @Override
    public int insertDataSourceEntity(DataSourceEntity dataSourceEntity)
    {
        dataSourceEntity.setCreateTime(DateUtils.getNowDate());
        return dataSourceEntityMapper.insertDataSourceEntity(dataSourceEntity);
    }

    /**
     * 修改数据源信息
     * 
     * @param dataSourceEntity 数据源信息
     * @return 结果
     */
    @Override
    public int updateDataSourceEntity(DataSourceEntity dataSourceEntity)
    {
        dataSourceEntity.setUpdateTime(DateUtils.getNowDate());
        return dataSourceEntityMapper.updateDataSourceEntity(dataSourceEntity);
    }

    /**
     * 批量删除数据源信息
     * 
     * @param ids 需要删除的数据源信息主键
     * @return 结果
     */
    @Override
    public int deleteDataSourceEntityByIds(Integer[] ids)
    {
        return dataSourceEntityMapper.deleteDataSourceEntityByIds(ids);
    }

    /**
     * 删除数据源信息信息
     * 
     * @param id 数据源信息主键
     * @return 结果
     */
    @Override
    public int deleteDataSourceEntityById(Integer id)
    {
        return dataSourceEntityMapper.deleteDataSourceEntityById(id);
    }
}
