package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataSourceTypeEntityMapper;
import com.czsj.dataCenter.domain.DataSourceTypeEntity;
import com.czsj.dataCenter.service.IDataSourceTypeEntityService;

/**
 * 数据源分类信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataSourceTypeEntityServiceImpl implements IDataSourceTypeEntityService 
{
    @Autowired
    private DataSourceTypeEntityMapper dataSourceTypeEntityMapper;

    /**
     * 查询数据源分类信息
     * 
     * @param id 数据源分类信息主键
     * @return 数据源分类信息
     */
    @Override
    public DataSourceTypeEntity selectDataSourceTypeEntityById(Integer id)
    {
        return dataSourceTypeEntityMapper.selectDataSourceTypeEntityById(id);
    }

    /**
     * 查询数据源分类信息列表
     * 
     * @param dataSourceTypeEntity 数据源分类信息
     * @return 数据源分类信息
     */
    @Override
    public List<DataSourceTypeEntity> selectDataSourceTypeEntityList(DataSourceTypeEntity dataSourceTypeEntity)
    {
        return dataSourceTypeEntityMapper.selectDataSourceTypeEntityList(dataSourceTypeEntity);
    }

    /**
     * 新增数据源分类信息
     * 
     * @param dataSourceTypeEntity 数据源分类信息
     * @return 结果
     */
    @Override
    public int insertDataSourceTypeEntity(DataSourceTypeEntity dataSourceTypeEntity)
    {
        dataSourceTypeEntity.setCreateTime(DateUtils.getNowDate());
        return dataSourceTypeEntityMapper.insertDataSourceTypeEntity(dataSourceTypeEntity);
    }

    /**
     * 修改数据源分类信息
     * 
     * @param dataSourceTypeEntity 数据源分类信息
     * @return 结果
     */
    @Override
    public int updateDataSourceTypeEntity(DataSourceTypeEntity dataSourceTypeEntity)
    {
        dataSourceTypeEntity.setUpdateTime(DateUtils.getNowDate());
        return dataSourceTypeEntityMapper.updateDataSourceTypeEntity(dataSourceTypeEntity);
    }

    /**
     * 批量删除数据源分类信息
     * 
     * @param ids 需要删除的数据源分类信息主键
     * @return 结果
     */
    @Override
    public int deleteDataSourceTypeEntityByIds(Integer[] ids)
    {
        return dataSourceTypeEntityMapper.deleteDataSourceTypeEntityByIds(ids);
    }

    /**
     * 删除数据源分类信息信息
     * 
     * @param id 数据源分类信息主键
     * @return 结果
     */
    @Override
    public int deleteDataSourceTypeEntityById(Integer id)
    {
        return dataSourceTypeEntityMapper.deleteDataSourceTypeEntityById(id);
    }
}
