package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataTableFieldMapper;
import com.czsj.dataCenter.domain.DataTableField;
import com.czsj.dataCenter.service.IDataTableFieldService;

/**
 * 数据库字段信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataTableFieldServiceImpl implements IDataTableFieldService 
{
    @Autowired
    private DataTableFieldMapper dataTableFieldMapper;

    /**
     * 查询数据库字段信息
     * 
     * @param id 数据库字段信息主键
     * @return 数据库字段信息
     */
    @Override
    public DataTableField selectDataTableFieldById(Integer id)
    {
        return dataTableFieldMapper.selectDataTableFieldById(id);
    }

    /**
     * 查询数据库字段信息列表
     * 
     * @param dataTableField 数据库字段信息
     * @return 数据库字段信息
     */
    @Override
    public List<DataTableField> selectDataTableFieldList(DataTableField dataTableField)
    {
        return dataTableFieldMapper.selectDataTableFieldList(dataTableField);
    }

    /**
     * 新增数据库字段信息
     * 
     * @param dataTableField 数据库字段信息
     * @return 结果
     */
    @Override
    public int insertDataTableField(DataTableField dataTableField)
    {
        return dataTableFieldMapper.insertDataTableField(dataTableField);
    }

    /**
     * 修改数据库字段信息
     * 
     * @param dataTableField 数据库字段信息
     * @return 结果
     */
    @Override
    public int updateDataTableField(DataTableField dataTableField)
    {
        dataTableField.setUpdateTime(DateUtils.getNowDate());
        return dataTableFieldMapper.updateDataTableField(dataTableField);
    }

    /**
     * 批量删除数据库字段信息
     * 
     * @param ids 需要删除的数据库字段信息主键
     * @return 结果
     */
    @Override
    public int deleteDataTableFieldByIds(Integer[] ids)
    {
        return dataTableFieldMapper.deleteDataTableFieldByIds(ids);
    }

    /**
     * 删除数据库字段信息信息
     * 
     * @param id 数据库字段信息主键
     * @return 结果
     */
    @Override
    public int deleteDataTableFieldById(Integer id)
    {
        return dataTableFieldMapper.deleteDataTableFieldById(id);
    }
}
