package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataTableMapper;
import com.czsj.dataCenter.domain.DataTable;
import com.czsj.dataCenter.service.IDataTableService;

/**
 * 数据库信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataTableServiceImpl implements IDataTableService 
{
    @Autowired
    private DataTableMapper dataTableMapper;

    /**
     * 查询数据库信息
     * 
     * @param id 数据库信息主键
     * @return 数据库信息
     */
    @Override
    public DataTable selectDataTableById(Integer id)
    {
        return dataTableMapper.selectDataTableById(id);
    }

    /**
     * 查询数据库信息列表
     * 
     * @param dataTable 数据库信息
     * @return 数据库信息
     */
    @Override
    public List<DataTable> selectDataTableList(DataTable dataTable)
    {
        return dataTableMapper.selectDataTableList(dataTable);
    }

    /**
     * 新增数据库信息
     * 
     * @param dataTable 数据库信息
     * @return 结果
     */
    @Override
    public int insertDataTable(DataTable dataTable)
    {
        dataTable.setCreateTime(DateUtils.getNowDate());
        return dataTableMapper.insertDataTable(dataTable);
    }

    /**
     * 修改数据库信息
     * 
     * @param dataTable 数据库信息
     * @return 结果
     */
    @Override
    public int updateDataTable(DataTable dataTable)
    {
        dataTable.setUpdateTime(DateUtils.getNowDate());
        return dataTableMapper.updateDataTable(dataTable);
    }

    /**
     * 批量删除数据库信息
     * 
     * @param ids 需要删除的数据库信息主键
     * @return 结果
     */
    @Override
    public int deleteDataTableByIds(Integer[] ids)
    {
        return dataTableMapper.deleteDataTableByIds(ids);
    }

    /**
     * 删除数据库信息信息
     * 
     * @param id 数据库信息主键
     * @return 结果
     */
    @Override
    public int deleteDataTableById(Integer id)
    {
        return dataTableMapper.deleteDataTableById(id);
    }
}
