package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataTaskConfigEntityMapper;
import com.czsj.dataCenter.domain.DataTaskConfigEntity;
import com.czsj.dataCenter.service.IDataTaskConfigEntityService;

/**
 * 任务JOB块配置信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataTaskConfigEntityServiceImpl implements IDataTaskConfigEntityService 
{
    @Autowired
    private DataTaskConfigEntityMapper dataTaskConfigEntityMapper;

    /**
     * 查询任务JOB块配置信息
     * 
     * @param id 任务JOB块配置信息主键
     * @return 任务JOB块配置信息
     */
    @Override
    public DataTaskConfigEntity selectDataTaskConfigEntityById(Integer id)
    {
        return dataTaskConfigEntityMapper.selectDataTaskConfigEntityById(id);
    }

    /**
     * 查询任务JOB块配置信息列表
     * 
     * @param dataTaskConfigEntity 任务JOB块配置信息
     * @return 任务JOB块配置信息
     */
    @Override
    public List<DataTaskConfigEntity> selectDataTaskConfigEntityList(DataTaskConfigEntity dataTaskConfigEntity)
    {
        return dataTaskConfigEntityMapper.selectDataTaskConfigEntityList(dataTaskConfigEntity);
    }

    /**
     * 新增任务JOB块配置信息
     * 
     * @param dataTaskConfigEntity 任务JOB块配置信息
     * @return 结果
     */
    @Override
    public int insertDataTaskConfigEntity(DataTaskConfigEntity dataTaskConfigEntity)
    {
        dataTaskConfigEntity.setCreateTime(DateUtils.getNowDate());
        return dataTaskConfigEntityMapper.insertDataTaskConfigEntity(dataTaskConfigEntity);
    }

    /**
     * 修改任务JOB块配置信息
     * 
     * @param dataTaskConfigEntity 任务JOB块配置信息
     * @return 结果
     */
    @Override
    public int updateDataTaskConfigEntity(DataTaskConfigEntity dataTaskConfigEntity)
    {
        dataTaskConfigEntity.setUpdateTime(DateUtils.getNowDate());
        return dataTaskConfigEntityMapper.updateDataTaskConfigEntity(dataTaskConfigEntity);
    }

    /**
     * 批量删除任务JOB块配置信息
     * 
     * @param ids 需要删除的任务JOB块配置信息主键
     * @return 结果
     */
    @Override
    public int deleteDataTaskConfigEntityByIds(Integer[] ids)
    {
        return dataTaskConfigEntityMapper.deleteDataTaskConfigEntityByIds(ids);
    }

    /**
     * 删除任务JOB块配置信息信息
     * 
     * @param id 任务JOB块配置信息主键
     * @return 结果
     */
    @Override
    public int deleteDataTaskConfigEntityById(Integer id)
    {
        return dataTaskConfigEntityMapper.deleteDataTaskConfigEntityById(id);
    }
}
