package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataTaskEntityMapper;
import com.czsj.dataCenter.domain.DataTaskEntity;
import com.czsj.dataCenter.service.IDataTaskEntityService;

/**
 * 任务主体信息Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataTaskEntityServiceImpl implements IDataTaskEntityService 
{
    @Autowired
    private DataTaskEntityMapper dataTaskEntityMapper;

    /**
     * 查询任务主体信息
     * 
     * @param id 任务主体信息主键
     * @return 任务主体信息
     */
    @Override
    public DataTaskEntity selectDataTaskEntityById(Integer id)
    {
        return dataTaskEntityMapper.selectDataTaskEntityById(id);
    }

    /**
     * 查询任务主体信息列表
     * 
     * @param dataTaskEntity 任务主体信息
     * @return 任务主体信息
     */
    @Override
    public List<DataTaskEntity> selectDataTaskEntityList(DataTaskEntity dataTaskEntity)
    {
        return dataTaskEntityMapper.selectDataTaskEntityList(dataTaskEntity);
    }

    /**
     * 新增任务主体信息
     * 
     * @param dataTaskEntity 任务主体信息
     * @return 结果
     */
    @Override
    public int insertDataTaskEntity(DataTaskEntity dataTaskEntity)
    {
        dataTaskEntity.setCreateTime(DateUtils.getNowDate());
        return dataTaskEntityMapper.insertDataTaskEntity(dataTaskEntity);
    }

    /**
     * 修改任务主体信息
     * 
     * @param dataTaskEntity 任务主体信息
     * @return 结果
     */
    @Override
    public int updateDataTaskEntity(DataTaskEntity dataTaskEntity)
    {
        dataTaskEntity.setUpdateTime(DateUtils.getNowDate());
        return dataTaskEntityMapper.updateDataTaskEntity(dataTaskEntity);
    }

    /**
     * 批量删除任务主体信息
     * 
     * @param ids 需要删除的任务主体信息主键
     * @return 结果
     */
    @Override
    public int deleteDataTaskEntityByIds(Integer[] ids)
    {
        return dataTaskEntityMapper.deleteDataTaskEntityByIds(ids);
    }

    /**
     * 删除任务主体信息信息
     * 
     * @param id 任务主体信息主键
     * @return 结果
     */
    @Override
    public int deleteDataTaskEntityById(Integer id)
    {
        return dataTaskEntityMapper.deleteDataTaskEntityById(id);
    }
}
