package com.czsj.dataCenter.service.impl;

import java.util.List;
import com.czsj.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.czsj.dataCenter.mapper.DataTaskMakeUpEntityMapper;
import com.czsj.dataCenter.domain.DataTaskMakeUpEntity;
import com.czsj.dataCenter.service.IDataTaskMakeUpEntityService;

/**
 * 任务配置组成数据Service业务层处理
 * 
 * @author czsj
 * @date 2024-12-08
 */
@Service
public class DataTaskMakeUpEntityServiceImpl implements IDataTaskMakeUpEntityService 
{
    @Autowired
    private DataTaskMakeUpEntityMapper dataTaskMakeUpEntityMapper;

    /**
     * 查询任务配置组成数据
     * 
     * @param id 任务配置组成数据主键
     * @return 任务配置组成数据
     */
    @Override
    public DataTaskMakeUpEntity selectDataTaskMakeUpEntityById(Integer id)
    {
        return dataTaskMakeUpEntityMapper.selectDataTaskMakeUpEntityById(id);
    }

    /**
     * 查询任务配置组成数据列表
     * 
     * @param dataTaskMakeUpEntity 任务配置组成数据
     * @return 任务配置组成数据
     */
    @Override
    public List<DataTaskMakeUpEntity> selectDataTaskMakeUpEntityList(DataTaskMakeUpEntity dataTaskMakeUpEntity)
    {
        return dataTaskMakeUpEntityMapper.selectDataTaskMakeUpEntityList(dataTaskMakeUpEntity);
    }

    /**
     * 新增任务配置组成数据
     * 
     * @param dataTaskMakeUpEntity 任务配置组成数据
     * @return 结果
     */
    @Override
    public int insertDataTaskMakeUpEntity(DataTaskMakeUpEntity dataTaskMakeUpEntity)
    {
        dataTaskMakeUpEntity.setCreateTime(DateUtils.getNowDate());
        return dataTaskMakeUpEntityMapper.insertDataTaskMakeUpEntity(dataTaskMakeUpEntity);
    }

    /**
     * 修改任务配置组成数据
     * 
     * @param dataTaskMakeUpEntity 任务配置组成数据
     * @return 结果
     */
    @Override
    public int updateDataTaskMakeUpEntity(DataTaskMakeUpEntity dataTaskMakeUpEntity)
    {
        dataTaskMakeUpEntity.setUpdateTime(DateUtils.getNowDate());
        return dataTaskMakeUpEntityMapper.updateDataTaskMakeUpEntity(dataTaskMakeUpEntity);
    }

    /**
     * 批量删除任务配置组成数据
     * 
     * @param ids 需要删除的任务配置组成数据主键
     * @return 结果
     */
    @Override
    public int deleteDataTaskMakeUpEntityByIds(Integer[] ids)
    {
        return dataTaskMakeUpEntityMapper.deleteDataTaskMakeUpEntityByIds(ids);
    }

    /**
     * 删除任务配置组成数据信息
     * 
     * @param id 任务配置组成数据主键
     * @return 结果
     */
    @Override
    public int deleteDataTaskMakeUpEntityById(Integer id)
    {
        return dataTaskMakeUpEntityMapper.deleteDataTaskMakeUpEntityById(id);
    }
}
